@@ -1,15 +1,29 @@
 """PythonHere app."""
+# pylint: disable=wrong-import-order,wrong-import-position
+
+from launcher_here import try_startup_script
+
+try:
+    try_startup_script()  # run script entrypoint, if it was passed
+except Exception as exc:
+    startup_script_exception = exc  # pylint: disable=invalid-name
+else:
+    startup_script_exception = None  # pylint: disable=invalid-name
+
 import asyncio
 import os
 from pathlib import Path
 import sys
+import threading
 from typing import Any, Dict
 
 from kivy.app import App
+from kivy.clock import Clock
+from kivy.config import Config, ConfigParser
 from kivy.logger import Logger
 
-from enum_here import ScreenName
-from exception_manager_here import install_exception_handler
+from enum_here import ScreenName, ServerState
+from exception_manager_here import install_exception_handler, show_exception_popup
 from patches_here import monkeypatch_kivy
 from server_here import run_ssh_server
 from window_here import reset_window_environment
@@ -38,6 +52,17 @@ class PythonHereApp(App):
         upload_dir.mkdir(exist_ok=True)
         return str(upload_dir)
 
+    @property
+    def config_path(self) -> str:
+        """Path to the application config file."""
+        root_dir = Path(self.user_data_dir or ".").resolve()
+        return str(root_dir / "config.ini")
+
+    def load_config(self) -> ConfigParser:
+        """Returning the application configuration."""
+        Config.read(self.config_path)  # Override the configuration file location
+        return super().load_config()
+
     def build(self):
         """Initialize application UI."""
         super().build()
@@ -51,13 +76,11 @@ class PythonHereApp(App):
                 "root": self.root,
             }
         )
-
         self.update_server_config_status()
-        self.root.switch_screen(
-            ScreenName.here
-            if self.ssh_server_config_ready.is_set()
-            else ScreenName.settings
-        )
+        if startup_script_exception:
+            Clock.schedule_once(
+                lambda _: show_exception_popup(startup_script_exception), 0
+            )
 
     def run_app(self):
         """Run application and SSH server tasks."""
@@ -81,10 +104,30 @@ class PythonHereApp(App):
         if self.get_running_app():
             self.stop()
 
+        await self.cancel_asyncio_tasks()
+
+    async def cancel_asyncio_tasks(self):
+        """Cancel all asyncio tasks."""
+        tasks = [
+            task for task in asyncio.all_tasks() if task is not asyncio.current_task()
+        ]
+        if tasks:
+            for task in tasks:
+                task.cancel()
+            await asyncio.wait(tasks, timeout=1)
+
     def update_server_config_status(self):
-        """Check and update value of the `ssh_server_config_ready`."""
-        if all(self.get_pythonhere_config().values()):
-            self.ssh_server_config_ready.set()
+        """Check and update value of the `ssh_server_config_ready`, update screen."""
+
+        def update():
+            if all(self.get_pythonhere_config().values()):
+                self.ssh_server_config_ready.set()
+            screen.update()
+
+        screen = self.root.ids.here_screen_manager
+        screen.current = ServerState.starting_server
+        self.root.switch_screen(ScreenName.here)
+        threading.Thread(name="update_server_config_status", target=update).start()
 
     def get_pythonhere_config(self):
         """Return user settings for SSH server."""
